(checkbox {:keys [valpath ATOM validation-function]})Create a checkbox
Create a checkbox
(map-structure v)Produce a map with the same key-structure from the vector
Produce a map with the same key-structure from the vector
(render-application fm A & [pathv])Render a browser form based on an input [sorted] map fm, with values to be stored/updated in atom A.
Use an array-map or sorted-map as fm if you want to maintain order
Render a browser form based on an input [sorted] map `fm`, with values to be stored/updated in atom `A`. Use an array-map or sorted-map as `fm` if you want to maintain order
(render-label {:keys [for-id label-text subtext]})Create a label to go into a .row
Create a label to go into a .row
(render-review schema application)Parse the application map and render the review based on the ordered schema of the application, with values in application expected to be as given by render-application.
Resulting form will be read-only with no changes possible.
Parse the application map and render the review based on the ordered `schema` of the application, with values in `application` expected to be as given by `render-application`. Resulting form will be read-only with no changes possible.
(reset-default default-schema-vec)(reset-default A default-schema-vec)Reset the given atom to a default state based on a default map, where it will possess each of the (possibly nested) structural elements of the given default, but values only according to an internal :default
Reset the given atom to a default state based on a default map, where it will possess each of the (possibly nested) structural elements of the given default, but values only according to an internal :default
(tinput ATOM valpath & [opt-map])Produce data-bound inputs for a given map, updating ATOM on change. opt-map specifies options including display variables.
Produce data-bound inputs for a given map, updating `ATOM` on change. `opt-map` specifies options including display variables.
(to-validation f & [error-message])Given a predicate, wrap it properly to be a validation function for tinput.
Validation function runs on the input at every change, altering the validity of the element as prescribed. It waits for .checkValidity on the input to explain the error
Given a predicate, wrap it properly to be a validation function for tinput. Validation function runs on the input at every change, altering the validity of the element as prescribed. It waits for .checkValidity on the input to explain the error
(togglebox {:keys [label content valpath ATOM default-value]})Builds a group which, when toggled, displays its :content
Builds a group which, when toggled, displays its `:content`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |